from setuptools import setup

setup(
    name='Flask-NYC',
    version='0.1.0',
    description='New York Flask Meetup',
    author='Andy Dirnberger',
    author_email='dirn@dirnonline.com',
    url='http://flask-nyc.org',
    py_modules=['flask_nyc'],
)
